package org.globus.transfer.reliable.service.client;

import org.globus.transfer.reliable.service.UserSubjectUtil;
import org.globus.transfer.reliable.service.cache.ConnectionManager;
import org.globus.transfer.reliable.service.cache.SingleConnectionImpl;
import org.globus.transfer.reliable.service.cache.ConnectionParameter;
import org.globus.transfer.reliable.service.database.RftDBException;
import org.globus.transfer.reliable.service.exception.RftException;
import org.globus.transfer.reliable.service.exception.RftTransientException;
import org.ietf.jgss.GSSCredential;

public class DeleteClient implements Client
{
    private SingleConnectionImpl connection;
    private ConnectionManager connectionManager;
    
    /**
     * Create a DeleteClient
     * @param params
     * @param rftOptions
     * @param credential
     * @throws RftException
     * @throws RftTransientException
     */
    public DeleteClient(
           ConnectionParameter  params,
           GSSCredential        credential,
           ConnectionManager    connectionManager)
    throws RftException, RftTransientException
    {
    	if (params == null) {
            throw new RftException("parameter for connection " +
                "must not be null");
        }
        if (credential == null) {
        	throw new RftException("credential must not be null");
        }
        if (connectionManager == null) {
            throw new RftException("connectionManager must not be null");
        }

    	this.connectionManager = connectionManager;
    	this.connection = (SingleConnectionImpl)
            connectionManager.getConnection(
                ConnectionManager.SINGLE_CONNECTION,
                params,
                credential,
                UserSubjectUtil.getUserSubject(params.getRFTOptions()));
    }

    /**
     * Delete a file or a directory
     * @throws RftDBException 
     * @throws RftException If a directory shall be removed and the GridFTP
     *                      server does not support the RDEL command
     * @throws RftTransientException If any other GridFTP server interaction
     *                               error occurs.
     */
    public void process() 
    throws RftException, RftTransientException, RftDBException
    {
        boolean success = false;

        try
        {
            connection.delete();
            connection.updateLastUsed();
            this.connectionManager.addConnection(connection);
            success = true;
        }
        finally
        {
            if(!success)
            {
                connection.closeConnection();
            }
        }

    }

}
